@@ -1,15 +1,23 @@
 ;; About the package
 (define *name* "Guile Library")
 (define *description* "Common modules for Guile Scheme")
-(define *version* "0.2.6.1")
-(define *updated* "July 2018")
+(define *version* "0.2.7")
+(define *updated* "March 2021")
 (define *authors*
-  '(("Andy Wingo" . "wingo at pobox.com")
-    ("Richard Todd" . "richardt at vzavenue.net")))
+  '(("Andreas Rottmann" .  "rotty at debian dot org")
+    ("Andy Wingo" . "wingo at pobox dot com")
+    ("Richard Todd" . "richardt at vzavenue dot net")
+    ("Neil W. Van Dyke" . "neil at neilvandyke dot org")
+    ("David Pirotte" . "david at altosw dot be")
+    ("Christopher Baines" . "mail at cbaines dot net")
+    ("Göran Weinhold" . "weinhold at debian dot org")
+    ("Ricardo Wurmus" . "rekado at elephly dot net")
+    ("Ludovic Courtès" . "ludo at gnu dot org")
+    ("Maxim Cournoyer" . "maxim dot cournoyer at gmail dot com")))
 
 ;; Copying the documentation
-(define *copyright-holder* "Andy Wingo, Richard Todd")
-(define *years* '(2003 2007 2010 2011 2016 2017 2018))
+(define *copyright-holder* "Andreas Rottmann, Andy Wingo, Richard Todd, Neil W. Van Dyke, David Pirotte, Christopher Baines, Göran Weinhold, Ricardo Wurmus, Ludovic Courtès, Maxim Cournoyer")
+(define *years* '(2003 2007 2010 2011 2016 2017 2018 2021))
 (define *permissions*
   "Permission is granted to copy, distribute and/or
 modify this document under the terms of the GNU Free
